@@ -27,3 +27,11 @@ def post_api(path, api_func, app):
 	temporary_func.__name__ = 'rand_func_name_%s'%rand_str
 	# 関数の登録 (関数名を毎回変えるため、デコレータをバラして書いている)
 	app.route(path, methods = ["post"])(temporary_func)
+
+# call post api [flaspi]
+def call_post_api(path, data):
+	res = requests.post(path, json = data)
+	# レスポンスの分解
+	status_code = res.status_code
+	json_str = res.text
+	return status_code, json_str
